@@ -131,6 +131,7 @@ greeter_ctrl_handler (GIOChannel *source,
     GreeterItemInfo *conversation_info;
     static GnomeCanvasItem *disabled_cover = NULL;
     gchar *language;
+    gchar *selected_user = NULL;
 
     /* If this is not incoming i/o then return */
     if (cond != G_IO_IN) 
@@ -178,8 +179,14 @@ greeter_ctrl_handler (GIOChannel *source,
 		greeter_probably_login_prompt = FALSE;
 	}
 	greeter_ignore_buttons (FALSE);
+
 	greeter_item_pam_prompt (tmp, PW_ENTRY_SIZE, TRUE);
 	g_free (tmp);
+
+	/* Reselect selected user if any */
+	selected_user = greeter_item_ulist_get_selected_user ();
+	if (greeter_probably_login_prompt == TRUE && selected_user != NULL)
+		greeter_item_ulist_select_user (selected_user);
 	break;
 
     case GDM_NOECHO:
@@ -193,6 +200,7 @@ greeter_ctrl_handler (GIOChannel *source,
 	greeter_ignore_buttons (FALSE);
 	greeter_item_pam_prompt (tmp, PW_ENTRY_SIZE, FALSE);
 	g_free (tmp);
+
 	break;
 
     case GDM_MSG:
@@ -249,10 +257,10 @@ greeter_ctrl_handler (GIOChannel *source,
 	buf[len-1] = '\0';
 
 	tmp = ve_locale_to_utf8 (buf);
-	session = gdm_session_lookup (tmp);
+	session = greeter_session_lookup (tmp);
 	g_free (tmp);
 
-	if (gdm_get_save_session () == GTK_RESPONSE_CANCEL) {
+	if (greeter_save_session () == GTK_RESPONSE_CANCEL) {
 	     printf ("%c%s\n", STX, GDM_RESPONSE_CANCEL);
 	} else {
 	    tmp = ve_locale_from_utf8 (session);
@@ -278,7 +286,7 @@ greeter_ctrl_handler (GIOChannel *source,
     case GDM_SSESS:
         g_io_channel_read_chars (source, buf, PIPE_SIZE-1, &len, NULL); /* Empty */
 
-	if (gdm_get_save_session () == GTK_RESPONSE_YES)
+	if (greeter_save_session () == GTK_RESPONSE_YES)
 	  printf ("%cY\n", STX);
 	else
 	  printf ("%c\n", STX);
@@ -318,7 +326,7 @@ greeter_ctrl_handler (GIOChannel *source,
 	printf ("%c\n", STX);
 	fflush (stdout);
 	greeter_ignore_buttons (FALSE);
-	greeter_item_ulist_enable ();
+        greeter_item_ulist_enable ();
 
 	break;
 
@@ -512,6 +520,7 @@ greeter_cancel_handler (GreeterItemInfo *info,
 {
    if (ignore_buttons == FALSE)
      {
+       greeter_item_ulist_unset_selected_user ();
        greeter_item_ulist_disable ();
        greeter_ignore_buttons (TRUE);
        printf ("%c%c%c\n", STX, BEL, GDM_INTERRUPT_CANCEL);
@@ -792,6 +801,7 @@ gdm_read_config (void)
 
 	/* Keys not to include in reread_config */
 	gdm_config_get_string (GDM_KEY_SESSION_DESKTOP_DIR);
+	gdm_config_get_string (GDM_KEY_PID_FILE);
 	gdm_config_get_string (GDM_KEY_PRE_FETCH_PROGRAM);
 
 	gdmcomm_comm_bulk_stop ();
